pub enum DispatchError {
LockRejected,
InvalidInterfacePath(String),
InvalidFunction(String),
MissingResponse,
RuntimeException(Error),
InvalidArgumentList,
UnsupportedType(String),
ResourceCreationError(ResourceCreationError),
ResourceReceiveError(ResourceReceiveError),
}Expand description
Errors that can occur when dispatching a function call to plugins.
Returned inside a cardinality wrapper from
Binding::dispatch
when a function call fails at runtime.
Variants
LockRejected
Failed to acquire lock on plugin instance (another call is in progress).
InvalidInterfacePath(String)
The specified interface path doesn’t match any known interface.
InvalidFunction(String)
The specified function doesn’t exist on the interface.
MissingResponse
Function was expected to return a value but didn’t.
RuntimeException(Error)
The WASM function threw an exception during execution.
InvalidArgumentList
The provided arguments don’t match the function signature.
UnsupportedType(String)
Async types (Future, Stream, ErrorContext) are not yet supported for cross-plugin transfer.
ResourceCreationError(ResourceCreationError)
Failed to create a resource handle for cross-plugin transfer.
ResourceReceiveError(ResourceReceiveError)
Failed to receive a resource handle from another plugin.