pub struct Function { /* private fields */ }Expand description
Metadata about a function declared by an interface.
Provides information needed during linking to wire up cross-plugin dispatch.
Implementations
Sourceimpl Function
impl Function
Sourcepub fn new(kind: FunctionKind, return_kind: ReturnKind) -> Self
pub fn new(kind: FunctionKind, return_kind: ReturnKind) -> Self
Creates a new function metadata entry.
Sourcepub fn return_kind(&self) -> ReturnKind
pub fn return_kind(&self) -> ReturnKind
The function’s return kind for dispatch handling.
Sourcepub fn kind(&self) -> FunctionKind
pub fn kind(&self) -> FunctionKind
Whether this function is freestanding or a resource method.