pub struct Interface { /* private fields */ }Expand description
A single WIT interface within a Binding.
Each interface declares functions and resources that implementers must export. Note that the interface name is not a part of the struct but rather a key in a hash map provided to the Binding constructor. This is to prevent duplicate interface names.
let binding: Binding<String, Ctx, AtMostOne<String, PluginInstance<Ctx>>> = Binding::new(
"my:package",
HashMap::from([
( "interface-a".to_string(), Interface::new( HashMap::new(), HashSet::new() )),
( "interface-b".to_string(), Interface::new( HashMap::new(), HashSet::new() )),
]),
AtMostOne( None ),
);Implementations