PartialResult

Type Alias PartialResult 

pub type PartialResult<T, F, E> = Result<(T, Vec<E>), (F, Vec<E>)>;
Represents an operation that may partially succeed or fail. Ok: Core success data plus errors from partial failures that allowed completion. Err: Primary failure cause plus errors that likely contributed to the overall failure.

Aliased Type

pub enum PartialResult<T, F, E> {
    Ok((T, Vec<E>)),
    Err((F, Vec<E>)),
}

Variants

1.0.0

Ok((T, Vec<E>))

Contains the success value

1.0.0

Err((F, Vec<E>))

Contains the error value