Remap

Struct Remap 

pub struct Remap { /* private fields */ }
Describes where a requested interface is found in a plugin’s exports.

Plugin::remap_interfaces stores these values in a map whose key is the requested interface name from the Binding. The Remap value then describes the interface name and item names actually exported by that plugin.

Examples

use std::collections::HashMap;
use wasm_link::Remap;

let interface_only = Remap::found_as( "legacy-root" );
let one_item = Remap::resolves_item( "get-value", "legacy-get-value" );
let many_items = Remap::item_resolution_table( HashMap::from([
	( "get-value".to_string(), "legacy-get-value".to_string() ),
]));
let interface_and_items = Remap::found_as_with_item_resolution_table(
	"legacy-root",
	HashMap::from([( "get-value".to_string(), "legacy-get-value".to_string() )]),
);

Implementations

Source

impl Remap

pub fn found_as(interface: impl Into<String>) -> Self

Creates a remap where the requested interface is found under another exported name.

pub fn resolves_item( requested_item: impl Into<String>, exported_item: impl Into<String>, ) -> Self

Creates a remap where one requested item resolves to another exported item name.

The first argument is the requested item name. The second argument is the item name exported by the plugin.

pub fn item_resolution_table(item_resolution_table: ItemResolutionTable) -> Self

Creates a remap from an item resolution table.

The table direction is requested item name -> exported item name.

pub fn found_as_with_item_resolution_table( interface: impl Into<String>, item_resolution_table: ItemResolutionTable, ) -> Self

Creates a remap for both the interface name and its item names.

The item table direction is requested item name -> exported item name.