pub type PartialResult<T, F, E> = Result<(T, Vec<E>), (F, Vec<E>)>;Expand description
Represents an operation that may partially succeed or fail. Ok: Core success data plus errors from partial failures that allowed completion. Err: Primary failure cause plus errors that likely contributed to the overall failure.
Aliased Type
pub enum PartialResult<T, F, E> {
Ok((T, Vec<E>)),
Err((F, Vec<E>)),
}